summaryrefslogtreecommitdiffstats
path: root/ksvg/impl/SVGMaskElementImpl.h
diff options
context:
space:
mode:
Diffstat (limited to 'ksvg/impl/SVGMaskElementImpl.h')
-rw-r--r--ksvg/impl/SVGMaskElementImpl.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/ksvg/impl/SVGMaskElementImpl.h b/ksvg/impl/SVGMaskElementImpl.h
index 5b61d713..2a96967c 100644
--- a/ksvg/impl/SVGMaskElementImpl.h
+++ b/ksvg/impl/SVGMaskElementImpl.h
@@ -89,10 +89,10 @@ public:
Mask createMask(SVGShapeImpl *referencingElement);
// Compute the mask on a given tqshape, taking into account all masks defined
// on the tqshape's ancestors. This is a workaround for us not having a buffer
// for container elements, so we can't mask containers directly.
- static TQByteArray maskRectangle(SVGShapeImpl *tqshape, const TQRect& screenRectangle);
+ static TQByteArray maskRectangle(SVGShapeImpl *shape, const TQRect& screenRectangle);
private:
class CacheKey
@@ -89,10 +89,10 @@ public:
Mask createMask(SVGShapeImpl *referencingElement);
- // Compute the mask on a given tqshape, taking into account all masks defined
- // on the tqshape's ancestors. This is a workaround for us not having a buffer
+ // Compute the mask on a given shape, taking into account all masks defined
+ // on the shape's ancestors. This is a workaround for us not having a buffer
// for container elements, so we can't mask containers directly.